@@ -19,11 +19,11 @@ Ixchel::Actions::sagan_merged - Generated a merged base/include for Sagan.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.0.2
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 =head1 SYNOPSIS
 
@@ -268,8 +268,10 @@ sub action {
 		print $results->{status_text};
 	}
 
-	if ( !defined( $results->{errors}[0] ) ) {
-		$results->{ok} = 1;
+	if ( !defined( $self->{results}{errors}[0] ) ) {
+		$self->{results}{ok} = 1;
+	} else {
+		$self->{results}{ok} = 0;
 	}
 
 	unlink($tmp_base);
